@@ -157,6 +157,18 @@
 		[titleField setStringValue:[track title]];
 	if ([track filesizeString])
 		[filesizeField setStringValue:[track filesizeString]];
+    
+  if ([track image])
+  {
+    NSImage *image = [[NSImage alloc] init];
+    [image addRepresentation:[track image]];
+    [imageView setImage:image];
+    [image release];
+  }
+  else
+  {
+    [imageView setImage:nil];
+  }
 	
 	[track retain];
 	[displayedTrack release];
@@ -185,6 +197,8 @@
 	if ([dataFile filename])
 		[titleField setStringValue:[dataFile filename]];
 	[filesizeField setStringValue:[dataFile sizeString]];
+  
+  [imageView setImage:nil];
 	
 	[displayedTrack release];
 	displayedTrack = nil;
@@ -236,7 +250,6 @@
 	[filesizeField setEnabled:enable];
 	[codecField setEnabled:enable];
 	[writeTagButton setEnabled:enable];
-  [albumArtButton setEnabled:enable];
 	[yearField setEnabled:enable];
 	
 	[titleField setEditable:enable];
@@ -268,6 +281,7 @@
 	[filesizeField setStringValue:@""];
 	[codecField setStringValue:@""];
 	[yearField setStringValue:@""];
+  [imageView setImage:nil];
 	[displayedTrack release];
 	displayedTrack = nil;
 }
