@@ -139,6 +139,15 @@
 {
 	[theNJB setTurbo:[preferences turbo]];
   [theNJB setCreateAlbumFiles:[preferences createAlbumFiles]];
+  if ([preferences createAlbumFiles])
+  {
+    [theNJB setUploadAlbumArt:[preferences uploadAlbumArt]];
+    if ([preferences uploadAlbumArt])
+    {
+      [theNJB setAlbumArtWidth:[preferences albumArtWidth]];
+      [theNJB setAlbumArtHeight:[preferences albumArtHeight]];
+    }
+  }
 	
 	// set up NSConnection between threads so the queue can call us 
 	NSPort *port1;
@@ -300,10 +309,9 @@
 	
 	[[njbQueue lock] lock];
 	[[njbQueue queue] addObject:connect];
-	
-	[connect release];
-	
 	[[njbQueue lock] unlockWithCondition:([[njbQueue queue] isEmpty] ? NO_QUEUE_ITEMS : SOME_QUEUE_ITEMS)];
+  
+  [connect release];
 }
 
 - (void)disconnectFromNJB
@@ -314,10 +322,9 @@
 	
 	[[njbQueue lock] lock];
 	[[njbQueue queue] addObject:disconnect];
-	
-	[disconnect release];
-	
 	[[njbQueue lock] unlockWithCondition:([[njbQueue queue] isEmpty] ? NO_QUEUE_ITEMS : SOME_QUEUE_ITEMS)];
+  
+  [disconnect release];
 }
 
 // menu methods
