@@ -568,6 +568,8 @@
 		[track setYear:[[thisTrackDict valueForKey:@"Year"] unsignedIntValue]];
 		[track setTrackNumber:[[thisTrackDict valueForKey:@"Track Number"] unsignedIntValue]];
 		[track setFilesize:[[thisTrackDict valueForKey:@"Size"] unsignedLongLongValue]];
+    [track setDateAdded:[thisTrackDict valueForKey:@"Date Added"]];
+    [track setRating:[[thisTrackDict valueForKey:@"Rating"] unsignedIntValue]];
 			
 		[iTunesArrayController addObject:track];
 		[track release];
@@ -681,41 +683,4 @@
 		return [super canCopyToNJB];
 }
 
-- (IBAction)uploadAlbumArt:(id)sender
-{
-  NSOpenPanel *panel = [NSOpenPanel openPanel];
-	
-	[panel setCanChooseFiles:YES];
-	[panel setCanChooseDirectories:NO];
-	
-	[panel beginSheetForDirectory:nil
-													 file:nil
-													types:[NSArray arrayWithObjects:@"jpg", @"jpeg", nil]
-								 modalForWindow:windowMain //[self window]
-									modalDelegate:self
-								 didEndSelector:@selector(uploadAlbumArtPanelDidEnd:returnCode:contextInfo:)
-										contextInfo:NULL];
-}
-
-- (void)uploadAlbumArtPanelDidEnd:(NSOpenPanel *)openPanel returnCode:(int)returnCode contextInfo:(void *)x
-{
-  Track *track = (Track *)[[arrayController arrangedObjects] objectAtIndex:[njbTable selectedRow]];
-
-  if (returnCode == NSOKButton)
-	{
-    NSLog([NSString stringWithFormat:@"uploading art %@ to track %@", [openPanel filename], track]);
-	}
-
-  NJBQueueItem *uploadArt = [[NJBQueueItem alloc] initWithTarget:theNJB withSelector:@selector(uploadAlbumArt:forTrack:)
-                                                      withObject:[openPanel filename]];
-  [uploadArt setObject2:track];
-	[uploadArt setStatus:STATUS_UPLOADING_ALBUM_ART];
-		
-	NSString *description = [NSString stringWithFormat:NSLocalizedString(@"Uploading album art for album '%@'", nil), [track album]];
-	[self addToQueue:uploadArt withSubItems:nil withDescription:description];
-  
-	[uploadArt release];
-  
-}
-
 @end
\ No newline at end of file
