@@ -241,6 +241,13 @@ StatusDisplayer *statusDisplayerGlobal;
   }
 }
 
+/*
+//TEST need for objectproplist debug in connect
+#include "/Users/richard/njb/XNJB/libmtp/src/ptp-pack.c"
+#include <fcntl.h>
+//!TEST
+*/
+
 /* connect to the NJB
  */
 - (NJBTransactionResult *)connect
@@ -396,7 +403,52 @@ StatusDisplayer *statusDisplayerGlobal;
 
 	// send notification, make sure this is last so all variables are set above
 	[statusDisplayer postNotificationName:NOTIFICATION_CONNECTED object:self];
-		
+  
+  
+ /* 
+  // TEST to read in objectproplist data from a file to debug
+  
+  NSLog(@"Starting test");
+
+  //NSString *filename = @"/Users/richard/njb/sansa-e280-crash.log";
+  NSString *filename = @"/Users/richard/njb/sansa-e260-crash.log";
+
+  NSFileManager *fileManager = [[NSFileManager alloc] init];
+	NSDictionary *fileAttributes = [fileManager fileAttributesAtPath:filename traverseLink:YES];
+  unsigned int encodedlen = [[fileAttributes objectForKey:NSFileSize] unsignedIntValue];
+  unsigned int len = encodedlen / 2;
+  char *data = malloc(len);
+  
+  int fd = open([filename cString], O_RDONLY);
+  
+  char cur[2];
+  int i = 0;
+  
+  for (i = 0; i < len; i++)
+  {
+    read(fd, &cur, 2);
+    data[i] = strtol(&cur, NULL, 16);
+  }
+
+  MTPProperties *props = NULL;
+  
+  int nrofprops = ptp_unpack_OPL(device->params, data, &props, len);
+
+  for (i = 0; i < nrofprops; i++)
+  {
+    NSLog(@"Property 0x%x, data type 0x%x, handle 0x%x", props[i].property, props[i].datatype, props[i].ObjectHandle);
+    if (props[i].datatype == PTP_DTC_STR)
+      NSLog(@"    prop string value %s", props[i].propval.str);
+  }
+  
+  close(fd);
+  free(data);
+  // free props
+  
+  // !TEST
+	*/
+    
+      	
 	return [[[NJBTransactionResult alloc] initWithSuccess:YES] autorelease];
 }
 
@@ -636,6 +688,7 @@ StatusDisplayer *statusDisplayerGlobal;
 			// duration is in milliseconds
 			[myTrack setLength:track->duration/1000];
 			[myTrack setTrackNumber:track->tracknumber];
+      [myTrack setRating:track->rating];
 			
 			if (track->date != NULL)
 			{
@@ -774,7 +827,8 @@ StatusDisplayer *statusDisplayerGlobal;
     if (createAlbumFiles)
     {
       Album *album = [self addTrack:track ToAlbumWithName:[track album]];
-      [self uploadAlbumArt:[track image] forAlbum:album];
+      if (uploadAlbumArt)
+        [self uploadAlbumArt:[track image] forAlbum:album];
     }
 		
 		 LIBMTP_destroy_track_t(trackmeta);
@@ -787,6 +841,8 @@ StatusDisplayer *statusDisplayerGlobal;
 	[self updateDiskSpace];
 	
 	// update my cache
+  // TOOD: should we do this?
+  [track setImage:nil];
 	[cachedTrackList addObject:track];
 	// tell others the track list has changed
 	[statusDisplayer postNotificationName:NOTIFICATION_TRACK_LIST_MODIFIED object:self];
@@ -1029,7 +1085,7 @@ StatusDisplayer *statusDisplayerGlobal;
 		}
 		LIBMTP_destroy_track_t(libmtp_track);
     
-    if (createAlbumFiles && [newTrack image])
+    if (createAlbumFiles && [newTrack image] && uploadAlbumArt)
     {
       [self uploadAlbumArtForTrack:newTrack];
     }
@@ -2055,6 +2111,7 @@ int mtp_progress(uint64_t const sent, uint64_t const total, void const * const d
 		libmtp_track->filename = strdup([[track filename] UTF8String]);
 	else
 		libmtp_track->filename = NULL;
+  libmtp_track->rating = [track rating];
 	libmtp_track->item_id = [track itemID];
 		
 	return libmtp_track;
@@ -2254,8 +2311,8 @@ int mtp_progress(uint64_t const sent, uint64_t const total, void const * const d
   NSImage *image = [[NSImage alloc] init];
   [image addRepresentation:imageRep];
   NSSize size;
-  size.width = 100;
-  size.height = 100;
+  size.width = albumArtWidth;
+  size.height = albumArtHeight;
   NSImage *scaledImage = [image imageByScalingProportionallyToSize:size];
   NSDictionary *properties = [NSDictionary dictionaryWithObject:[NSNumber numberWithFloat:0.9] forKey:NSImageCompressionFactor];
   NSBitmapImageRep *bitmapImageRepScaled = [NSBitmapImageRep imageRepWithData:[scaledImage TIFFRepresentation]];
@@ -2312,12 +2369,7 @@ int mtp_progress(uint64_t const sent, uint64_t const total, void const * const d
       break;
   }
   
-  // TODO: if track is not in the album already, but the album exists, we need to add it
-  // we should also add an option that makes all the album files correctly
-  // need to warn if too big - can we rescale?  Can we read from tags?  iTunes?
-  // need to add @"Uploading Album Art" to localized strings
-  // update UI for all languages
-  // disable album art button for local files, or add album art to local tags (hard probably)
+  // TODO: need to add @"Uploading Album Art" to localized strings
   
   if (album == nil)
   {
@@ -2334,6 +2386,21 @@ int mtp_progress(uint64_t const sent, uint64_t const total, void const * const d
   createAlbumFiles = newCreateAlbumFiles;
 }
 
+- (void)setUploadAlbumArt:(BOOL)newUploadAlbumArt
+{
+  uploadAlbumArt = newUploadAlbumArt;
+}
+
+- (void)setAlbumArtWidth:(unsigned)newAlbumArtWidth
+{
+  albumArtWidth = newAlbumArtWidth;
+}
+
+- (void)setAlbumArtHeight:(unsigned)newAlbumArtHeight
+{
+  albumArtHeight = newAlbumArtHeight;
+}
+
 - (void)cancelCurrentTransaction
 {
   cancelCurrentTransaction = YES;
