@@ -39,6 +39,11 @@
 {
 	if (self = [super init])
 	{
+    object1 = nil;
+    object2 = nil;
+    target = nil;
+    itemsToCancelIfFail = nil;
+    
 		[self setTarget:newTarget];
 		[self setSelector:newSelector];
 		[self setObject1:newObject];
@@ -189,13 +194,22 @@
  * then I am released in the original thread, reducing the retain count of my objects to 1 which are then autoreleased
  * which kills them.  So this is required.  Safe because I will be released and retained the same number of times (if I am
  * to be freed).  Same for the objects.																																																								 
+ * UPDATE: I can't remember what the problems were, but this causes many memory leaks.  Added in releases on release of me to cancel out.
  */
-- (id)retain
+/*- (id)retain
 {
 	[object1 retain];
 	[object2 retain];
 	[target retain];
 	return [super retain];
-}
+}*/
+/*
+- (void)release
+{
+  [object1 release];
+  [object2 release];
+  [target release];
+  return [super release];
+}*/
 
 @end
