@@ -63,5 +63,11 @@
 - (void)setiTunesMusicLibraryLocation:(NSString *)iTunesMusicLibraryLocation;
 - (BOOL)createAlbumFiles;
 - (void)setCreateAlbumFiles:(BOOL)createAlbumFiles;
+- (BOOL)uploadAlbumArt;
+- (void)setUploadAlbumArt:(BOOL)uploadAlbumArt;
+- (unsigned)albumArtWidth;
+- (void)setAlbumArtWidth:(unsigned)albumArtWidth;
+- (unsigned)albumArtHeight;
+- (void)setAlbumArtHeight:(unsigned)albumArtHeight;
 
 @end
