@@ -268,6 +268,42 @@
   [theNJB setCreateAlbumFiles:createAlbumFiles];
 }
 
+- (BOOL)uploadAlbumArt
+{
+  return [defaults boolForKey:PREF_KEY_UPLOAD_ALBUM_ART];
+}
+
+- (void)setUploadAlbumArt:(BOOL)uploadAlbumArt
+{
+  [defaults setObject:[NSNumber numberWithBool:uploadAlbumArt] forKey:PREF_KEY_UPLOAD_ALBUM_ART];
+  
+  [theNJB setUploadAlbumArt:uploadAlbumArt];
+}
+
+- (unsigned)albumArtWidth
+{
+  return [defaults integerForKey:PREF_KEY_ALBUM_ART_WIDTH];
+}
+
+- (void)setAlbumArtWidth:(unsigned)albumArtWidth
+{
+  [defaults setObject:[NSNumber numberWithUnsignedInt:albumArtWidth] forKey:PREF_KEY_ALBUM_ART_WIDTH];
+  
+  [theNJB setAlbumArtWidth:albumArtWidth];
+}
+
+- (unsigned)albumArtHeight
+{
+  return [defaults integerForKey:PREF_KEY_ALBUM_ART_HEIGHT];
+}
+
+- (void)setAlbumArtHeight:(unsigned)albumArtHeight
+{
+  [defaults setObject:[NSNumber numberWithUnsignedInt:albumArtHeight] forKey:PREF_KEY_ALBUM_ART_HEIGHT];
+  
+  [theNJB setAlbumArtHeight:albumArtHeight];
+}
+
 /**********************/
 
 - (void)registerDefaults
@@ -318,6 +354,12 @@
 	[defaultValues setObject:DEFAULT_PREF_KEY_ITUNES_LOCATION forKey:PREF_KEY_ITUNES_LOCATION];
   // CREATE_ALBUM_FILES
   [defaultValues setObject:DEFAULT_PREF_KEY_CREATE_ALBUM_FILES forKey:PREF_KEY_CREATE_ALBUM_FILES];
+  // UPLOAD_ALBUM_ART
+  [defaultValues setObject:DEFAULT_PREF_KEY_UPLOAD_ALBUM_ART forKey:PREF_KEY_UPLOAD_ALBUM_ART];
+  // ALBUM_ART_WIDTH
+  [defaultValues setObject:DEFAULT_PREF_KEY_ALBUM_ART_WIDTH forKey:PREF_KEY_ALBUM_ART_WIDTH];
+  // ALBUM_ART_HEIGHT
+  [defaultValues setObject:DEFAULT_PREF_KEY_ALBUM_ART_HEIGHT forKey:PREF_KEY_ALBUM_ART_HEIGHT];
 	
 	[defaults registerDefaults:defaultValues];
 }
