@@ -33,6 +33,9 @@
 	IBOutlet NSTextField *downloadedTrackDir;
 	IBOutlet NSTextField *iTunesMusicLibraryLocation;
   IBOutlet NSButton *createAlbumFiles;
+  IBOutlet NSButton *uploadAlbumArt;
+  IBOutlet NSTextField *albumArtHeight;
+  IBOutlet NSTextField *albumArtWidth;
 	
 	Preferences *preferences;
 	NSTabView *tabView;
@@ -57,5 +60,6 @@
 - (IBAction)enableTurbo:(id)sender;
 - (IBAction)iTunesIntegration:(id)sender;
 - (IBAction)createAlbumFiles:(id)sender;
+- (IBAction)uploadAlbumArt:(id)sender;
 
 @end
