@@ -21,6 +21,8 @@
 	unsigned year;
 	unsigned long long filesize;
   NSBitmapImageRep *image;
+  NSDate *dateAdded;
+  int rating;
 }
 - (id)initWithTrack:(Track *)track;
 - (NSString *)title;
@@ -50,6 +52,10 @@
 - (void)fileTypeFromExtension;
 - (void)setImage:(NSBitmapImageRep *)newImage;
 - (NSBitmapImageRep *)image;
+- (void)setDateAdded:(NSDate *)newDateAdded;
+- (NSDate *)dateAdded;
+- (void)setRating:(unsigned int)newRating;
+- (unsigned int)rating;
 
 - (NSComparisonResult)compareByLength:(Track *)other;
 - (NSComparisonResult)compareUnsignedInts:(unsigned)mine withOther:(unsigned)theirs;
