@@ -33,7 +33,7 @@
 	Track *track = [[Track alloc] init];
 	
 	[track setFilesize:sb.st_size];
-	[track setCodec:CODEC_WMA];
+	[track setFileType:LIBMTP_FILETYPE_WMA];
 	[track setFullPath:filename];
 	
 	metadata_t meta;
