@@ -60,6 +60,12 @@
 #define DEFAULT_PREF_KEY_ITUNES_LOCATION @"~/Music/iTunes/iTunes Music Library.xml"
 #define PREF_KEY_CREATE_ALBUM_FILES @"createAlbumFiles"
 #define DEFAULT_PREF_KEY_CREATE_ALBUM_FILES [NSNumber numberWithBool:YES]
+#define PREF_KEY_UPLOAD_ALBUM_ART @"uploadAlbumArt"
+#define DEFAULT_PREF_KEY_UPLOAD_ALBUM_ART [NSNumber numberWithBool:YES]
+#define PREF_KEY_ALBUM_ART_WIDTH @"albumArtWidth"
+#define DEFAULT_PREF_KEY_ALBUM_ART_WIDTH [NSNumber numberWithInt:100]
+#define PREF_KEY_ALBUM_ART_HEIGHT @"albumArtHeight"
+#define DEFAULT_PREF_KEY_ALBUM_ART_HEIGHT [NSNumber numberWithInt:100]
 
 // Notifications
 #define NOTIFICATION_CONNECTED @"XNJBConnected"
