@@ -6,18 +6,8 @@
 //  Copyright (c) 2003 __MyCompanyName__. All rights reserved.
 //
 
-#ifdef __APPLE__
 #import "V23FrameSet.h"
 #import "zlib.h"
-#else
-#include "V23FrameSet.h"
-#include "zlib.h"
-
-#include <Foundation/NSArray.h>
-#include <Foundation/NSData.h>
-#include <Foundation/NSDictionary.h>
-#endif
-
 
 @implementation V23FrameSet
 -(id)init:(NSMutableData *)Frames version:(int)Minor validFrameSet:(NSDictionary *)FrameSet  frameSet:(NSMutableDictionary *)frameSet offset:(int)Offset taglength:(unsigned int)totalLength
