@@ -641,7 +641,8 @@
       return [NSMutableArray arrayWithCapacity:0];
        
     //obtain a cstring representation of the genre string
-    const char * tempPointer = [String cString];
+    
+    const char * tempPointer = [String lossyCString];
     int start = 0;
     int end = 0;
     int foundNull = 0;
