@@ -5,10 +5,11 @@
  * based on Enrique Jorreto Ledesma's work on the original program by 
  * Shaun Jackman and Linus Walleij.
  *
- * Copyright (C) 2003-2007 Linus Walleij <triad@df.lth.se>
+ * Copyright (C) 2003-2008 Linus Walleij <triad@df.lth.se>
  * Copyright (C) 2003-2005 Shaun Jackman
  * Copyright (C) 2003-2005 Enrique Jorrete Ledesma
  * Copyright (C) 2006 Chris A. Debenham <chris@adebenham.com>
+ * Copyright (C) 2008 Nicolas Pennequin <nicolas.pennequin@free.fr>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -41,14 +42,15 @@ extern LIBMTP_folder_t *folders;
 extern LIBMTP_file_t *files;
 extern LIBMTP_mtpdevice_t *device;
 
-int sendtrack_function (char *, char *, char *, char *, char *, char *, uint16_t, uint16_t, uint16_t);
+int sendtrack_function (char *, char *, char *, char *, char *, char *, char *, char *, uint16_t, uint16_t, uint16_t);
 void sendtrack_command (int, char **);
 void sendtrack_usage (void);
 
 void sendtrack_usage (void)
 {
-  fprintf(stderr, "usage: sendtr [ -D debuglvl ] [ -q ] -t <title> -a <artist> -l <album>\n");
-  fprintf(stderr, "       -c <codec> -g <genre> -n <track number> -y <year> \n");
+  fprintf(stderr, "usage: sendtr [ -D debuglvl ] [ -q ]\n");
+  fprintf(stderr, "-t <title> -a <artist> -A <Album artist> -w <writer or composer>\n");
+  fprintf(stderr, "    -l <album> -c <codec> -g <genre> -n <track number> -y <year>\n");
   fprintf(stderr, "       -d <duration in seconds> <local path> <remote path>\n");
   fprintf(stderr, "(-q means the program will not ask for missing information.)\n");
 }
@@ -81,11 +83,80 @@ static char *prompt (const char *prompt, char *buffer, size_t bufsz, int require
   }
 }
 
-int sendtrack_function(char * from_path, char * to_path, char *partist, char *ptitle, char *pgenre, char *palbum, uint16_t tracknum, uint16_t length, uint16_t year)
+static int add_track_to_album(LIBMTP_album_t *albuminfo, LIBMTP_track_t *trackmeta)
+{
+  LIBMTP_album_t *album;
+  LIBMTP_album_t *found_album = NULL;
+  int ret;
+
+  /* Look for the album */
+  album = LIBMTP_Get_Album_List(device);
+  while(album != NULL) {
+    if ((album->name != NULL &&
+	album->artist != NULL &&
+	!strcmp(album->name, albuminfo->name) &&
+	!strcmp(album->artist, albuminfo->artist)) ||
+	  (album->name != NULL &&
+	album->composer != NULL &&
+	!strcmp(album->name, albuminfo->name) &&
+	!strcmp(album->composer, albuminfo->composer))) {
+      /* Disconnect this album for later use */
+      found_album = album;
+      album = album->next;
+      found_album->next = NULL;
+    } else {
+      LIBMTP_album_t *tmp;
+
+      tmp = album;
+      album = album->next;
+      LIBMTP_destroy_album_t(tmp);
+    }
+  }
+  
+  if (found_album != NULL) {
+    uint32_t *tracks;
+
+    tracks = (uint32_t *)malloc((found_album->no_tracks+1) * sizeof(uint32_t));
+    printf("Album \"%s\" found: updating...\n", found_album->name);
+    if (!tracks) {
+      printf("failed malloc in add_track_to_album()\n");
+      return 1;
+    }
+    found_album->no_tracks++;
+    if (found_album->tracks != NULL) {
+      memcpy(tracks, found_album->tracks, found_album->no_tracks * sizeof(uint32_t));
+      free(found_album->tracks);
+    }
+    tracks[found_album->no_tracks-1] = trackmeta->item_id;
+    found_album->tracks = tracks;
+    ret = LIBMTP_Update_Album(device, found_album);
+    LIBMTP_destroy_album_t(found_album);
+  } else {
+    uint32_t *trackid;
+    
+    trackid = (uint32_t *)malloc(sizeof(uint32_t));
+    *trackid = trackmeta->item_id;
+    albuminfo->tracks = trackid;
+    albuminfo->no_tracks = 1;
+    printf("Album doesn't exist: creating...\n");
+    ret = LIBMTP_Create_New_Album(device, albuminfo, 0);
+    /* albuminfo will be destroyed later by caller */
+  }
+  
+  if (ret != 0) {
+    printf("Error creating or updating album.\n");
+    LIBMTP_Dump_Errorstack(device);
+    LIBMTP_Clear_Errorstack(device);
+  } else {
+    printf("success!\n");
+  }
+  return ret;
+}
+
+int sendtrack_function(char * from_path, char * to_path, char *partist, char *palbumartist, char *ptitle, char *pgenre, char *palbum, char *pcomposer, uint16_t tracknum, uint16_t length, uint16_t year)
 {
-  printf("Sending track %s to %s\n",from_path,to_path);
   char *filename, *parent;
-  char artist[80], title[80], genre[80], album[80];
+  char artist[80], albumartist[80], title[80], genre[80], album[80], composer[80];
   char num[80];
   uint64_t filesize;
   uint32_t parent_id = 0;
@@ -95,7 +166,13 @@ int sendtrack_function(char * from_path, char * to_path, char *partist, char *pt
   struct stat sb;
 #endif
   LIBMTP_track_t *trackmeta;
+  LIBMTP_album_t *albuminfo;
+  int ret;
+
+  printf("Sending track %s to %s\n",from_path,to_path);
+
   trackmeta = LIBMTP_new_track_t();
+  albuminfo = LIBMTP_new_album_t();
 
   parent = dirname(to_path);
   filename = basename(to_path);
@@ -120,40 +197,38 @@ int sendtrack_function(char * from_path, char * to_path, char *partist, char *pt
     filesize = (uint64_t) sb.st_size;
 #endif
     trackmeta->filetype = find_filetype (from_path);
-    if ((trackmeta->filetype != LIBMTP_FILETYPE_MP3) 
-	&& (trackmeta->filetype != LIBMTP_FILETYPE_WAV) 
-	&& (trackmeta->filetype != LIBMTP_FILETYPE_OGG)
-	&& (trackmeta->filetype != LIBMTP_FILETYPE_MP4) 
-	&& (trackmeta->filetype != LIBMTP_FILETYPE_AAC) 
-	&& (trackmeta->filetype != LIBMTP_FILETYPE_M4A) 
-	&& (trackmeta->filetype != LIBMTP_FILETYPE_FLAC) 
-	&& (trackmeta->filetype != LIBMTP_FILETYPE_WMA)) {
-      printf("Not a valid codec: \"%s\"\n", LIBMTP_Get_Filetype_Description(trackmeta->filetype));
-      printf("Supported formats: MP3, WAV, OGG, MP4, AAC, M4A, FLAC, WMA\n");
+    if (!LIBMTP_FILETYPE_IS_TRACK(trackmeta->filetype)) {
+      printf("Not a valid track codec: \"%s\"\n", LIBMTP_Get_Filetype_Description(trackmeta->filetype));
       return 1;
     }
 
-    int ret;
-
     if (ptitle == NULL) {
       ptitle = prompt("Title", title, 80, 0);
     }
     if (!strlen(ptitle))
       ptitle = NULL;
 
-
     if (palbum == NULL) {
       palbum = prompt("Album", album, 80, 0);
     }
     if (!strlen(palbum))
       palbum = NULL;
 
+    if (palbumartist == NULL) {
+      palbumartist = prompt("Album artist", albumartist, 80, 0);
+    }
     if (partist == NULL) {
       partist = prompt("Artist", artist, 80, 0);
     }
     if (!strlen(partist))
       partist = NULL;
 
+    if (pcomposer == NULL) {
+      pcomposer = prompt("Writer or Composer", composer, 80, 0);
+    }
+    if (!strlen(pcomposer))
+      pcomposer = NULL;
+
     if (pgenre == NULL) {
       pgenre = prompt("Genre", genre, 80, 0);
     }
@@ -192,7 +267,6 @@ int sendtrack_function(char * from_path, char * to_path, char *partist, char *pt
         length = 0;
       }
     }
-
     
     printf("Sending track:\n");
     printf("Codec:     %s\n", LIBMTP_Get_Filetype_Description(trackmeta->filetype));
@@ -203,14 +277,28 @@ int sendtrack_function(char * from_path, char * to_path, char *partist, char *pt
     if (palbum) {
       printf("Album:     %s\n", palbum);
       trackmeta->album = strdup(palbum);
+      albuminfo->name = strdup(palbum);
+    }
+    if (palbumartist) {
+      printf("Album artist:    %s\n", palbumartist);
+      albuminfo->artist = strdup(palbumartist);
     }
     if (partist) {
       printf("Artist:    %s\n", partist);
       trackmeta->artist = strdup(partist);
+      if (palbumartist == NULL)
+      albuminfo->artist = strdup(partist);
+    }
+
+    if (pcomposer) {
+      printf("Writer or Composer:    %s\n", pcomposer);
+      trackmeta->composer = strdup(pcomposer);
+      albuminfo->composer = strdup(pcomposer);
     }
     if (pgenre) {
       printf("Genre:     %s\n", pgenre);
       trackmeta->genre = strdup(pgenre);
+      albuminfo->genre = strdup(pgenre);
     }
     if (year > 0) {
       char tmp[80];
@@ -245,8 +333,12 @@ int sendtrack_function(char * from_path, char * to_path, char *partist, char *pt
       printf("New track ID: %d\n", trackmeta->item_id);
     }
 
+/* Add here add to album call */
+		ret = add_track_to_album(albuminfo, trackmeta);
+
+    LIBMTP_destroy_album_t(albuminfo);
     LIBMTP_destroy_track_t(trackmeta);
-  
+
     return 0;
   }
   return 0;
@@ -257,6 +349,8 @@ void sendtrack_command (int argc, char **argv) {
   extern int optind;
   extern char *optarg;
   char *partist = NULL;
+  char *palbumartist = NULL;
+  char *pcomposer = NULL;
   char *ptitle = NULL;
   char *pgenre = NULL;
   char *pcodec = NULL;
@@ -266,7 +360,7 @@ void sendtrack_command (int argc, char **argv) {
   uint16_t year = 0;
   uint16_t quiet = 0;
   char *lang;
-  while ( (opt = getopt(argc, argv, "qD:t:a:l:c:g:n:d:y:")) != -1 ) {
+  while ( (opt = getopt(argc, argv, "qD:t:a:A:w:l:c:g:n:d:y:")) != -1 ) {
     switch (opt) {
     case 't':
       ptitle = strdup(optarg);
@@ -274,6 +368,12 @@ void sendtrack_command (int argc, char **argv) {
     case 'a':
       partist = strdup(optarg);
       break;
+    case 'A':
+      palbumartist = strdup(optarg);
+      break;
+    case 'w':
+      pcomposer = strdup(optarg);
+      break;
     case 'l':
       palbum = strdup(optarg);
       break;
@@ -322,6 +422,6 @@ void sendtrack_command (int argc, char **argv) {
     }
   }
   
-  printf("%s,%s,%s,%s,%s,%s,%d%d,%d\n",argv[0],argv[1],partist,ptitle,pgenre,palbum,tracknum, length, year);
-  sendtrack_function(argv[0],argv[1],partist,ptitle,pgenre,palbum, tracknum, length, year);
+  printf("%s,%s,%s,%s,%s,%s,%s,%s,%d%d,%d\n",argv[0],argv[1],partist,palbumartist,ptitle,pgenre,palbum,pcomposer,tracknum, length, year);
+  sendtrack_function(argv[0],argv[1],partist,palbumartist,ptitle,pgenre,palbum,pcomposer, tracknum, length, year);
 }
