@@ -3,7 +3,7 @@
  * Low-level USB interface glue towards libusb.
  *
  * Copyright (C) 2005-2007 Richard A. Low <richard@wentnet.com>
- * Copyright (C) 2005-2007 Linus Walleij <triad@df.lth.se>
+ * Copyright (C) 2005-2008 Linus Walleij <triad@df.lth.se>
  * Copyright (C) 2006-2007 Marcus Meissner
  * Copyright (C) 2007 Ted Bullock
  *
@@ -125,12 +125,14 @@ static struct usb_bus* init_usb()
  * Small recursive function to append a new usb_device to the linked list of
  * USB MTP devices
  * @param devlist dynamic linked list of pointers to usb devices with MTP 
- * properties.
- * @param next New USB MTP device to be added to list
- * @return nothing
+ *        properties, to be extended with new device.
+ * @param newdevice the new device to add.
+ * @param bus_location bus for this device.
+ * @return an extended array or NULL on failure.
  */
 static mtpdevice_list_t *append_to_mtpdevice_list(mtpdevice_list_t *devlist,
-				     struct usb_device *newdevice)
+						  struct usb_device *newdevice,
+						  uint32_t bus_location)
 {
   mtpdevice_list_t *new_list_entry;
   
@@ -140,6 +142,7 @@ static mtpdevice_list_t *append_to_mtpdevice_list(mtpdevice_list_t *devlist,
   }
   // Fill in USB device, if we *HAVE* to make a copy of the device do it here.
   new_list_entry->libusb_device = newdevice;
+  new_list_entry->bus_location = bus_location;
   new_list_entry->next = NULL;
   
   if (devlist == NULL) {
@@ -191,6 +194,7 @@ static int probe_device_descriptor(struct usb_device *dev, FILE *dumpfile)
 {
   usb_dev_handle *devh;
   unsigned char buf[1024], cmd;
+  int i;
   int ret;
   
   /* Don't examine hubs (no point in that) */
@@ -204,6 +208,38 @@ static int probe_device_descriptor(struct usb_device *dev, FILE *dumpfile)
     /* Could not open this device */
     return 0;
   }
+
+  /*
+   * Loop over the device configurations and interfaces. Nokia MTP-capable 
+   * handsets (possibly others) typically have the string "MTP" in their 
+   * MTP interface descriptions, that's how they can be detected, before
+   * we try the more esoteric "OS descriptors" (below).
+   */
+  for (i = 0; i < dev->descriptor.bNumConfigurations; i++) {
+    uint8_t j;
+    
+    for (j = 0; j < dev->config[i].bNumInterfaces; j++) {
+      int k;
+      for (k = 0; k < dev->config[i].interface[j].num_altsetting; k++) {
+        buf[0] = '\0';
+        ret = usb_get_string_simple(devh, 
+				    dev->config[i].interface[j].altsetting[k].iInterface, 
+				    (char *) buf, 
+				    1024);
+	if (ret < 3)
+	  continue;
+        if (strcmp((char *) buf, "MTP") == 0) {
+	  if (dumpfile != NULL) {
+            fprintf(dumpfile, "Configuration %d, interface %d, altsetting %d:\n", i, j, k);
+	    fprintf(dumpfile, "   Interface description contains the string \"MTP\"\n");
+	    fprintf(dumpfile, "   Device recognized as MTP, no further probing.\n");
+	  }
+          usb_close(devh);
+          return 1;
+        }
+      }
+    }
+  }
   
   /* Read the special descriptor */
   ret = usb_get_descriptor(devh, 0x03, 0xee, buf, sizeof(buf));
@@ -313,8 +349,8 @@ static int probe_device_descriptor(struct usb_device *dev, FILE *dumpfile)
  * This function scans through the connected usb devices on a machine and
  * if they match known Vendor and Product identifiers appends them to the
  * dynamic array mtp_device_list. Be sure to call 
- * <code>free(mtp_device_list)</code> when you are done with it, assuming it
- * is not NULL.
+ * <code>free_mtpdevice_list(mtp_device_list)</code> when you are done 
+ * with it, assuming it is not NULL.
  * @param mtp_device_list dynamic array of pointers to usb devices with MTP 
  *        properties (if this list is not empty, new entries will be appended
  *        to the list).
@@ -339,7 +375,9 @@ static LIBMTP_error_number_t get_mtp_usb_device_list(mtpdevice_list_t ** mtp_dev
           if(dev->descriptor.idVendor == mtp_device_table[i].vendor_id &&
             dev->descriptor.idProduct == mtp_device_table[i].product_id) {
             /* Append this usb device to the MTP device list */
-            *mtp_device_list = append_to_mtpdevice_list(*mtp_device_list, dev);
+            *mtp_device_list = append_to_mtpdevice_list(*mtp_device_list, 
+							dev, 
+							bus->location);
             found = 1;
             break;
           }
@@ -348,7 +386,9 @@ static LIBMTP_error_number_t get_mtp_usb_device_list(mtpdevice_list_t ** mtp_dev
         if (!found) {
           if (probe_device_descriptor(dev, NULL)) {
             /* Append this usb device to the MTP USB Device List */
-            *mtp_device_list = append_to_mtpdevice_list(*mtp_device_list, dev);
+            *mtp_device_list = append_to_mtpdevice_list(*mtp_device_list, 
+							dev,
+							bus->location);
           }
         }
       }
@@ -363,31 +403,106 @@ static LIBMTP_error_number_t get_mtp_usb_device_list(mtpdevice_list_t ** mtp_dev
 }
 
 /**
- * Detect the MTP device descriptor and return the VID and PID
- * of the first device found. This is a very low-level function
- * which is intended for use with <b>udev</b> or other hotplug
- * mechanisms. The idea is that a script may want to know if the
- * just plugged-in device was an MTP device or not.
+ * Detect the raw MTP device descriptors and return a list of
+ * of the devices found.
  * 
- * @param vid the Vendor ID (VID) of the first device found.
- * @param pid the Product ID (PID) of the first device found.
- * @return the number of detected devices or -1 if the call
- *         was unsuccessful.
+ * @param devices a pointer to a variable that will hold
+ *        the list of raw devices found. This may be NULL
+ *        on return if the number of detected devices is zero.
+ *        The user shall simply <code>free()</code> this
+ *        variable when finished with the raw devices,
+ *        in order to release memory.
+ * @param numdevs a pointer to an integer that will hold 
+ *        the number of devices in the list. This may
+ *        be 0.
+ * @return 0 if successful, any other value means failure.
  */
-int LIBMTP_Detect_Descriptor(uint16_t *vid, uint16_t *pid)
+int LIBMTP_Detect_Raw_Devices(LIBMTP_raw_device_t ** devices, 
+			      int * numdevs)
 {
-  mtpdevice_list_t *devlist;
-  LIBMTP_error_number_t ret;  
+  mtpdevice_list_t *devlist = NULL;
+  mtpdevice_list_t *dev;
+  LIBMTP_error_number_t ret;
+  LIBMTP_raw_device_t *retdevs;
+  int devs = 0;
+  int i, j;
 
   ret = get_mtp_usb_device_list(&devlist);
   if (ret != LIBMTP_ERROR_NONE) {
-    *vid = *pid = 0;
+    fprintf(stderr, "LIBMTP PANIC: get_mtp_usb_device_list() "
+	    "error code: %d on line %d\n", ret, __LINE__);
     return -1;
   }
-  *vid = devlist->libusb_device->descriptor.idVendor;
-  *pid = devlist->libusb_device->descriptor.idProduct;
+
+  // Get list size
+  dev = devlist;
+  while (dev != NULL) {
+    devs++;
+    dev = dev->next;
+  }
+  if (devs == 0) {
+    *devices = NULL;
+    *numdevs = 0;
+    return 0;
+  }
+  // Conjure a device list
+  retdevs = (LIBMTP_raw_device_t *) malloc(sizeof(LIBMTP_raw_device_t) * devs);
+  if (retdevs == NULL) {
+    // Out of memory
+    *devices = NULL;
+    *numdevs = 0;
+    return 1;
+  }
+  dev = devlist;
+  i = 0;
+  while (dev != NULL) {
+    int device_known = 0;
+
+    // Assign default device info
+    retdevs[i].device_entry.vendor = NULL;
+    retdevs[i].device_entry.vendor_id = dev->libusb_device->descriptor.idVendor;
+    retdevs[i].device_entry.product = NULL;
+    retdevs[i].device_entry.product_id = dev->libusb_device->descriptor.idProduct;
+    retdevs[i].device_entry.device_flags = 0x00000000U;
+    // See if we can locate some additional device flags
+    for(j = 0; j < mtp_device_table_size; j++) {
+      if(dev->libusb_device->descriptor.idVendor == mtp_device_table[j].vendor_id &&
+	 dev->libusb_device->descriptor.idProduct == mtp_device_table[j].product_id) {
+	device_known = 1;
+	retdevs[i].device_entry.vendor = mtp_device_table[j].vendor;
+	retdevs[i].device_entry.product = mtp_device_table[j].product;
+	retdevs[i].device_entry.device_flags = mtp_device_table[j].device_flags;
+#ifdef ENABLE_USB_BULK_DEBUG
+	// This device is known to the developers
+	fprintf(stderr, "Device %d (VID=%04x and PID=%04x) is a %s %s.\n", 
+		i,
+		dev->libusb_device->descriptor.idVendor,
+		dev->libusb_device->descriptor.idProduct,
+		mtp_device_table[j].vendor,
+		mtp_device_table[j].product);
+#endif
+	break;
+      }
+    }
+    if (!device_known) {
+      // This device is unknown to the developers
+      fprintf(stderr, "Device %d (VID=%04x and PID=%04x) is UNKNOWN.\n", 
+	      i,
+	      dev->libusb_device->descriptor.idVendor,
+	      dev->libusb_device->descriptor.idProduct);
+      fprintf(stderr, "Please report this VID/PID and the device model to the "
+	      "libmtp development team\n");
+    }
+    // Save the location on the bus
+    retdevs[i].bus_location = dev->bus_location;
+    retdevs[i].devnum = dev->libusb_device->devnum;
+    i++;
+    dev = dev->next;
+  }  
+  *devices = retdevs;
+  *numdevs = i;
   free_mtpdevice_list(devlist);
-  return 1;
+  return 0;
 }
 
 /**
@@ -501,7 +616,7 @@ ptp_read_func (
   while (curread < size) {
     
 #ifdef ENABLE_USB_BULK_DEBUG
-    printf("Remaining size to read: 0x%04x bytes\n", size - curread);
+    printf("Remaining size to read: 0x%04lx bytes\n", size - curread);
 #endif
     // check equal to condition here
     if (size - curread < CONTEXT_BLOCK_SIZE)
@@ -526,7 +641,7 @@ ptp_read_func (
 	     (unsigned int) toread, (unsigned int) (size-curread));
 
 #ifdef ENABLE_USB_BULK_DEBUG
-    printf("Reading in 0x%04x bytes\n", toread);
+    printf("Reading in 0x%04lx bytes\n", toread);
 #endif
     result = USB_BULK_READ(ptp_usb->handle, ptp_usb->inep, (char*)bytes, toread, USB_TIMEOUT);
 #ifdef ENABLE_USB_BULK_DEBUG
@@ -791,7 +906,12 @@ ptp_usb_sendreq (PTPParams* params, PTPContainer* req)
 	PTPUSBBulkContainer usbreq;
 	PTPDataHandler	memhandler;
 	unsigned long written, towrite;
+#ifdef ENABLE_USB_BULK_DEBUG
+	char txt[256];
 
+	(void) ptp_render_opcode (params, req->Code, sizeof(txt), txt);
+	printf("REQUEST: 0x%04x, %s\n", req->Code, txt);
+#endif
 	/* build appropriate USB container */
 	usbreq.length=htod32(PTP_USB_BULK_REQ_LEN-
 		(sizeof(uint32_t)*(5-req->Nparam)));
@@ -837,6 +957,9 @@ ptp_usb_senddata (PTPParams* params, PTPContainer* ptp,
 	uint32_t bytes_left_to_transfer;
 	PTPDataHandler memhandler;
 
+#ifdef ENABLE_USB_BULK_DEBUG
+	printf("SEND DATA PHASE\n");
+#endif
 	/* build appropriate USB container */
 	usbdata.length	= htod32(PTP_USB_BULK_HDR_LEN+size);
 	usbdata.type	= htod16(PTP_USB_CONTAINER_DATA);
@@ -922,6 +1045,9 @@ ptp_usb_getdata (PTPParams* params, PTPContainer* ptp, PTPDataHandler *handler)
 	unsigned long	written;
 	PTP_USB *ptp_usb = (PTP_USB *) params->data;
 
+#ifdef ENABLE_USB_BULK_DEBUG
+	printf("GET DATA PHASE\n");
+#endif
 	memset(&usbdata,0,sizeof(usbdata));
 	do {
 		unsigned long len, rlen;
@@ -1075,10 +1201,24 @@ ptp_usb_getresp (PTPParams* params, PTPContainer* resp)
 	PTPUSBBulkContainer usbresp;
 	PTP_USB *ptp_usb = (PTP_USB *)(params->data);
 
+#ifdef ENABLE_USB_BULK_DEBUG
+	printf("RESPONSE: ");
+#endif
 	memset(&usbresp,0,sizeof(usbresp));
 	/* read response, it should never be longer than sizeof(usbresp) */
 	ret = ptp_usb_getpacket(params, &usbresp, &rlen);
 
+	// Fix for bevahiour reported by Scott Snyder on Samsung YP-U3. The player
+	// sends a packet containing just zeroes of length 2 (up to 4 has been seen too)
+	// after a NULL packet when it should send the response. This code ignores
+	// such illegal packets.
+	while (ret==PTP_RC_OK && rlen<PTP_USB_BULK_HDR_LEN && usbresp.length==0) {
+	  ptp_debug (params, "ptp_usb_getresp: detected short response "
+		     "of %d bytes, expect problems! (re-reading "
+		     "response), rlen");
+	  ret = ptp_usb_getpacket(params, &usbresp, &rlen);
+	}
+
 	if (ret!=PTP_RC_OK) {
 		ret = PTP_ERROR_IO;
 	} else
@@ -1088,6 +1228,9 @@ ptp_usb_getresp (PTPParams* params, PTPContainer* resp)
 	if (dtoh16(usbresp.code)!=resp->Code) {
 		ret = dtoh16(usbresp.code);
 	}
+#ifdef ENABLE_USB_BULK_DEBUG
+	printf("%04x\n", ret);
+#endif
 	if (ret!=PTP_RC_OK) {
 /*		ptp_error (params,
 		"PTP: request code 0x%04x getting resp error 0x%04x",
@@ -1101,7 +1244,8 @@ ptp_usb_getresp (PTPParams* params, PTPContainer* resp)
 	if (ptp_usb->device_flags & DEVICE_FLAG_IGNORE_HEADER_ERRORS) {
 		if (resp->Transaction_ID != params->transaction_id-1) {
 			ptp_debug (params, "ptp_usb_getresp: detected a broken "
-				   "PTP header, transaction ID insane, expect problems! (But continuing)");
+				   "PTP header, transaction ID insane, expect "
+				   "problems! (But continuing)");
 			// Repair the header, so it won't wreak more havoc.
 			resp->Transaction_ID = params->transaction_id-1;
 		}
@@ -1311,7 +1455,16 @@ static void close_usb(PTP_USB* ptp_usb)
   // Commented out since it was confusing some
   // devices to do these things.
   if (!(ptp_usb->device_flags & DEVICE_FLAG_NO_RELEASE_INTERFACE)) {
-    // Clear any stalled endpoints
+    /*
+     * Clear any stalled endpoints
+     * On misbehaving devices designed for Windows/Mac, quote from:
+     * http://www2.one-eyed-alien.net/~mdharm/linux-usb/target_offenses.txt
+     * Device does Bad Things(tm) when it gets a GET_STATUS after CLEAR_HALT
+     * (...) Windows, when clearing a stall, only sends the CLEAR_HALT command, 
+     * and presumes that the stall has cleared.  Some devices actually choke 
+     * if the CLEAR_HALT is followed by a GET_STATUS (used to determine if the 
+     * STALL is persistant or not).
+     */
     clear_stall(ptp_usb);
     // Clear halts on any endpoints
     clear_halt(ptp_usb);
